/**
 * @file main.c
 * @author Jake G
 * @date 15 June 2024
 * @brief File contains the main function.
 *
 * This file contains the main logic loop and exists to setup the values
 * specific to the micro-controller. All other functions and configuration are
 * extracted into separate source files and headers for configuration.
 */

#include <stdio.h>
#define F_CPU 3333333UL

// This can prevent issues with utils/delay.h library with the gcc toolchain
#define __DELAY_BACKWARD_COMPATIBLE__

#include "RegEdit.h"
#include "SuperLoop.h"
#include "config.h"
#include "timer.h"
#include <avr/cpufunc.h> /* Required header file */
#include <avr/io.h>
#include <util/delay.h>

#define RELAYPIN (1 << 7)
#define RELAYREADINGPIN                                                        \
  (1 << 6) // It would be better to use PA7 so USART worked

// Set the function pointer for the delay func
void (*Delay_MicroSeconds)(double us) = _delay_us;


int main(int argc, char **argv) {

  // Setup for Infinite Loop
  SuperLoop_SetIterations(0);
  SuperLoop_Run();
}
